@@ -13,7 +13,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from keystoneclient import adapter
+from debtcollector import removals
 from stevedore import extension
 
 from designateclient import exceptions
@@ -21,6 +21,15 @@ from designateclient import utils
 from designateclient import version
 
 
+@removals.removed_class(
+    'designateclient.v1.Client',
+    replacement='designateclient.v2.client.Client',
+    message='Designate v1 API is being retired, and the v1 Client class will '
+    'stop functioning. Please update code to the '
+    'designateclient.v2.client.Client class. The API is deprecated',
+    version='2.2.0',
+    removal_version='?',
+    stacklevel=3)
 class Client(object):
     """Client for the Designate v1 API"""
 
@@ -32,7 +41,8 @@ class Client(object):
                  project_domain_id=None, auth_url=None, token=None,
                  endpoint_type='publicURL', region_name=None,
                  service_type='dns', insecure=False, session=None,
-                 cacert=None, all_tenants=None, edit_managed=None):
+                 cacert=None, all_tenants=None, edit_managed=None,
+                 timeout=None):
         """
         :param endpoint: Endpoint URL
         :param token: A token instead of username / password
@@ -62,7 +72,7 @@ class Client(object):
                 user_domain_name=user_domain_name,
                 token=token,
                 insecure=insecure,
-                cacert=cacert
+                cacert=cacert,
             )
 
         # NOTE: all_tenants and edit_managed are pulled from the session for
@@ -82,7 +92,7 @@ class Client(object):
         # an adapter around the session to not modify it's state.
         interface = endpoint_type.rstrip('URL')
 
-        self.session = adapter.Adapter(
+        self.session = utils.AdapterWithTimeout(
             session,
             auth=session.auth,
             endpoint_override=endpoint,
@@ -90,7 +100,8 @@ class Client(object):
             service_type=service_type,
             interface=interface,
             user_agent='python-designateclient-%s' % version.version_info,
-            version='1'
+            version='1',
+            timeout=timeout,
         )
 
         def _load_controller(ext):
@@ -126,7 +137,7 @@ class Client(object):
 
         if response.status_code == 400:
             raise exceptions.BadRequest(**response_payload)
-        elif response.status_code in (401, 403):
+        elif response.status_code in (401, 403, 413):
             raise exceptions.Forbidden(**response_payload)
         elif response.status_code == 404:
             raise exceptions.NotFound(**response_payload)
