@@ -1,8 +1,8 @@
 from __future__ import print_function
 import logging
 
-from keystoneclient.auth.identity import generic
-from keystoneclient import session as keystone_session
+from keystoneauth1.identity import generic
+from keystoneauth1 import session as keystone_session
 
 from designateclient import shell
 from designateclient.v2 import client
@@ -13,9 +13,11 @@ auth = generic.Password(
     auth_url=shell.env('OS_AUTH_URL'),
     username=shell.env('OS_USERNAME'),
     password=shell.env('OS_PASSWORD'),
-    tenant_name=shell.env('OS_TENANT_NAME'))
+    project_name=shell.env('OS_PROJECT_NAME'),
+    project_domain_id='default',
+    user_domain_id='default')
 
-session = keystone_session.Session(auth=auth)
+session = keystone_session.Session(auth=auth, timeout=10)
 
 client = client.Client(session=session)
 
